@@ -19,6 +19,7 @@ from esi.clients import esi_client_factory
 from esi.models import Token
 
 from .. import __title__
+from ..app_settings import SR_ESI_TIMEOUT_ENABLED
 from ..utils import LoggerAddTag
 
 
@@ -26,7 +27,6 @@ logger = LoggerAddTag(logging.getLogger(__name__), __title__)
 
 ESI_MAX_RETRIES = 3
 ESI_RETRY_SLEEP_SECS = 1
-ESI_API_TIMEOUT = 10
 
 _my_esi_client = None
 
@@ -37,7 +37,7 @@ def esi_fetch(
     has_pages: bool = False,
     token: Token = None,
     esi_client: object = None,
-    logger_tag: str = None
+    logger_tag: str = None,
 ) -> dict:
     """returns an response object from ESI, will retry on some HTTP errors.
     will automatically return all pages if requested
@@ -53,13 +53,13 @@ def esi_fetch(
     - logger_tag: every log message will start with this text in brackets
     """
     _, request_object = _fetch_main(
-        esi_path=esi_path, 
+        esi_path=esi_path,
         args=args,
         languages=None,
         has_pages=has_pages,
         esi_client=esi_client,
         token=token,
-        logger_tag=logger_tag
+        logger_tag=logger_tag,
     ).popitem()
     return request_object
 
@@ -71,7 +71,7 @@ def esi_fetch_with_localization(
     has_pages: bool = False,
     esi_client: object = None,
     token: Token = None,
-    logger_tag: str = None
+    logger_tag: str = None,
 ) -> dict:
     """returns dict of response objects from ESI
     will contain one full object items for each language if supported or just one
@@ -97,7 +97,7 @@ def esi_fetch_with_localization(
         has_pages=has_pages,
         esi_client=esi_client,
         token=token,
-        logger_tag=logger_tag
+        logger_tag=logger_tag,
     )
 
 
@@ -108,30 +108,30 @@ def _fetch_main(
     has_pages: bool,
     esi_client: object,
     token: Token,
-    logger_tag: str
+    logger_tag: str,
 ) -> dict:
     """returns dict of response objects from ESI with localization"""
 
     if not args:
         args = {}
-    
+
     if not languages:
         has_localization = False
-        languages = {'dummy'}
+        languages = {"dummy"}
     else:
         has_localization = True
 
     response_objects = dict()
     for language in languages:
         if has_localization:
-            args['language'] = language
+            args["language"] = language
         response_objects[language] = _fetch_with_paging(
-            esi_path=esi_path, 
+            esi_path=esi_path,
             args=args,
             has_pages=has_pages,
             esi_client=esi_client,
             token=token,
-            logger_tag=logger_tag
+            logger_tag=logger_tag,
         )
 
     return response_objects
@@ -143,29 +143,29 @@ def _fetch_with_paging(
     has_pages: bool = False,
     esi_client: object = None,
     token: Token = None,
-    logger_tag: str = None
+    logger_tag: str = None,
 ) -> dict:
-    """fetches esi objects incl. all pages if requested and returns them""" 
+    """fetches esi objects incl. all pages if requested and returns them"""
     response_object, pages = _fetch_with_retries(
-        esi_path=esi_path, 
-        args=args, 
-        has_pages=has_pages, 
+        esi_path=esi_path,
+        args=args,
+        has_pages=has_pages,
         esi_client=esi_client,
         token=token,
-        logger_tag=logger_tag
-    )        
+        logger_tag=logger_tag,
+    )
     if has_pages:
         for page in range(2, pages + 1):
             response_object_page, _ = _fetch_with_retries(
-                esi_path=esi_path, 
+                esi_path=esi_path,
                 args=args,
                 has_pages=has_pages,
                 page=page,
                 pages=pages,
                 esi_client=esi_client,
                 token=token,
-                logger_tag=logger_tag
-            )  
+                logger_tag=logger_tag,
+            )
             response_object += response_object_page
 
     return response_object
@@ -176,9 +176,9 @@ def _esi_client() -> object:
     global _my_esi_client
 
     if not _my_esi_client:
-        logger.info('Initializing esi client for esi_fetch....')
+        logger.info("Initializing esi client for esi_fetch....")
         _my_esi_client = esi_client_factory()
-    
+
     return _my_esi_client
 
 
@@ -190,7 +190,7 @@ def _fetch_with_retries(
     pages: int = None,
     esi_client: object = None,
     token: Token = None,
-    logger_tag: str = None
+    logger_tag: str = None,
 ) -> tuple:
     """Returns response object and pages from ESI, retries on 502s"""
 
@@ -224,40 +224,36 @@ def _prepare_esi_request(
     token: Token = None,
 ):
     """parses and validates input for esi request"""
-    esi_path_parts = esi_path.split('.')
+    esi_path_parts = esi_path.split(".")
     if len(esi_path_parts) != 2:
-        raise ValueError('Invalid esi_path')
+        raise ValueError("Invalid esi_path")
     esi_category_name = esi_path_parts[0]
     esi_method_name = esi_path_parts[1]
     if not esi_client:
         esi_client = _esi_client()
     if not hasattr(esi_client, esi_category_name):
-        raise ValueError(
-            'Invalid ESI category: %s' % esi_category_name
-        )
+        raise ValueError("Invalid ESI category: %s" % esi_category_name)
     esi_category = getattr(esi_client, esi_category_name)
     if not hasattr(esi_category, esi_method_name):
         raise ValueError(
-            'Invalid ESI method for %s category: %s'
+            "Invalid ESI method for %s category: %s"
             % (esi_category_name, esi_method_name)
         )
-    log_message_base = 'Fetching from ESI: {}'.format(esi_path)
+    log_message_base = "Fetching from ESI: {}".format(esi_path)
     if settings.DEBUG:
-        log_message_base += '({})'.format(
-            ', '.join([str(k) + '=' + str(v) for k, v in args.items()])
+        log_message_base += "({})".format(
+            ", ".join([str(k) + "=" + str(v) for k, v in args.items()])
         )
     if has_pages:
         if not page:
             page = 1
-        args['page'] = page
-        log_message_base += ' - Page {}/{}'.format(
-            page, pages if pages else '?'
-        )
+        args["page"] = page
+        log_message_base += " - Page {}/{}".format(page, pages if pages else "?")
     if token:
         if token.expired:
             token.refresh()
-        args['token'] = token.access_token
-    
+        args["token"] = token.access_token
+
     return esi_category, esi_method_name, log_message_base
 
 
@@ -275,46 +271,65 @@ def _execute_esi_request(
     """
     add_prefix = _make_logger_prefix(logger_tag)
     logger.info(add_prefix(log_message_base))
+    response_object = dict()
+    pages = 0
     for retry_count in range(ESI_MAX_RETRIES + 1):
         if retry_count > 0:
-            logger.warn(add_prefix(
-                '{} - Retry {} / {}'.format(
-                    log_message_base, retry_count, ESI_MAX_RETRIES
+            logger.warn(
+                add_prefix(
+                    "{} - Retry {} / {}".format(
+                        log_message_base, retry_count, ESI_MAX_RETRIES
+                    )
                 )
-            ))
-        try:                  
+            )
+        try:
             operation = getattr(esi_category, esi_method_name)(**args)
+            result_args = {"timeout": (5, 30)} if SR_ESI_TIMEOUT_ENABLED else {}
             if has_pages:
-                operation.also_return_response = True
-                response_object, response = operation.result(timeout=ESI_API_TIMEOUT)
-                if 'x-pages' in response.headers:
-                    pages = int(response.headers['x-pages'])
+                if hasattr(operation, "request_config"):
+                    operation.request_config.also_return_response = True
+                    response_object, response = operation.result(**result_args)
+                elif hasattr(operation, "also_return_response"):
+                    operation.also_return_response = True
+                    response_object, response = operation.result(**result_args)
+                else:
+                    logger.warning(
+                        "django-esi API is not fully compatible. "
+                        "Falling back to fetching first page only from ESI"
+                    )
+                    response_object = operation.result(**result_args)
+                    response = None
+
+                if response and "x-pages" in response.headers:
+                    pages = int(response.headers["x-pages"])
                 else:
                     pages = 0
             else:
-                response_object = operation.result()
+                response_object = operation.result(**result_args)
                 pages = 0
             break
 
         except (HTTPBadGateway, HTTPGatewayTimeout, HTTPServiceUnavailable) as ex:
-            logger.warn(add_prefix(
-                'HTTP error while trying to '
-                'fetch response_object from ESI: {}'.format(ex)
-            ))
+            logger.warn(
+                add_prefix(
+                    "HTTP error while trying to "
+                    "fetch response_object from ESI: {}".format(ex)
+                )
+            )
             if retry_count < ESI_MAX_RETRIES:
                 sleep_seconds = (ESI_RETRY_SLEEP_SECS * retry_count) ** 2
-                logger.info(add_prefix(
-                    'Waiting {} seconds until next retry'.format(sleep_seconds)
-                ))
+                logger.info(
+                    add_prefix(
+                        "Waiting {} seconds until next retry".format(sleep_seconds)
+                    )
+                )
                 sleep(sleep_seconds)
             else:
                 raise ex
-    
+
     return response_object, pages
 
 
 def _make_logger_prefix(tag: str = None):
     """creates a function to add logger prefix"""
-    return lambda text: '{}{}'.format(
-        (tag + ': ') if tag else '', text
-    )
+    return lambda text: "{}{}".format((tag + ": ") if tag else "", text)
